@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -355,7 +355,7 @@ EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str
 
 FunctionCodeTypeDef = TypedDict(
     "FunctionCodeTypeDef",
-    {"ZipFile": bytes, "S3Bucket": str, "S3Key": str, "S3ObjectVersion": str},
+    {"ZipFile": Union[bytes, IO[bytes]], "S3Bucket": str, "S3Key": str, "S3ObjectVersion": str},
     total=False,
 )
 
@@ -448,7 +448,7 @@ InvocationResponseTypeDef = TypedDict(
         "StatusCode": int,
         "FunctionError": str,
         "LogResult": str,
-        "Payload": bytes,
+        "Payload": IO[bytes],
         "ExecutedVersion": str,
     },
     total=False,
@@ -458,7 +458,7 @@ InvokeAsyncResponseTypeDef = TypedDict("InvokeAsyncResponseTypeDef", {"Status":
 
 LayerVersionContentInputTypeDef = TypedDict(
     "LayerVersionContentInputTypeDef",
-    {"S3Bucket": str, "S3Key": str, "S3ObjectVersion": str, "ZipFile": bytes},
+    {"S3Bucket": str, "S3Key": str, "S3ObjectVersion": str, "ZipFile": Union[bytes, IO[bytes]]},
     total=False,
 )
 
